"""
File in charge of easing the import of the program
"""
from .tty_ov import TTY
from .tty_ov import HLLs
from .tty_ov import ColouriseOutput as CO
from .tty_ov import AskQuestion as AQ


class ColouriseOutput(CO):
    """ A rebind of the same library to help you access the ressources """
    pass


class AskQuestion(AQ):
    """ A rebind of the same library to help you access the ressources """
    pass


class TTY_OV(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class TTY_Ov(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class Tty_Ov(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class TTYOV(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class TtyOv(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class tty_ov(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass


class tty(TTY):
    """ A name rebind to for those who whish to follow the library name """
    pass
